﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.EntityFrameworkCore;
using TodoList.Model;

namespace TodoList.Services
{
    public class TodoListService
    {
        private readonly TodoListDbContext _context;

        public TodoListService(TodoListDbContext context)
        {
            _context = context;
        }

        public List<List> GetLists(String name = null)
        {
            return _context.Lists
                .Where(l => l.Name.Contains(name ?? ""))
                .OrderBy(l => l.Name)
                .ToList();
        }

        public List GetListByID(int id)
        {
            return _context.Lists
                .Single(l => l.Id == id); // throws exception if id not found
        }

        public List<Item> GetItemsByListID(int id)
        {
            return _context.Items
                 .Where(i => i.ListId == id)
                 .ToList();
        }

        public void AddItemToList(Item item)
        {
            if (item == null)
                throw new ArgumentNullException(nameof(item), "The item to add must not be null.");

            _context.Items.Add(item);
            _context.SaveChanges();
        }

        public void ChangeListName(int id, String newName)
        {
            var list = _context.Lists
                 .Single(l => l.Id == id); // throws exception if id not found

            list.Name = newName;

            _context.SaveChanges();
        }

        public void RemoveItemByName(int id, String name)
        {
            Item item = _context.Items
                .Where(i => i.ListId == id)
                .FirstOrDefault(i => i.Name == name);

            if (item == null)
                return;

            _context.Items.Remove(item);
            _context.SaveChanges();
        }

    }
}
